/**********************************************************************
 *
 * GEOS - Geometry Engine Open Source
 * http://geos.osgeo.org
 *
 * Copyright (C) 2006 Refractions Research Inc.
 * Copyright (C) 2001-2002 Vivid Solutions Inc.
 *
 * This is free software; you can redistribute and/or modify it under
 * the terms of the GNU Lesser General Public Licence as published
 * by the Free Software Foundation. 
 * See the COPYING file for more information.
 *
 **********************************************************************/

#ifndef GEOS_INDEX_H
#define GEOS_INDEX_H

namespace geos {

/// Provides classes for various kinds of spatial indexes.
namespace index {

} // namespace geos.index
} // namespace geos

#include <geos/index/SpatialIndex.h>
#include <geos/index/ItemVisitor.h>

#endif // GEOS_INDEX_H
