/**********************************************************************
 *
 * GEOS - Geometry Engine Open Source
 * http://geos.osgeo.org
 *
 * Copyright (C) 2001-2002 Vivid Solutions Inc.
 * Copyright (C) 2006 Refractions Research Inc.
 *
 * This is free software; you can redistribute and/or modify it under
 * the terms of the GNU Lesser General Public Licence as published
 * by the Free Software Foundation. 
 * See the COPYING file for more information.
 *
 **********************************************************************/

#ifndef GEOS_OPDISTANCE_H
#define GEOS_OPDISTANCE_H

namespace geos {
namespace operation { // geos.operation

/// Provides classes for computing the distance between geometries
namespace distance { // geos.operation.distance

} // namespace geos.operation.distance
} // namespace geos.operation
} // namespace geos

//#include <geos/operation/distance/ConnectedElementLocationFilter.h>
//#include <geos/operation/distance/ConnectedElementPointFilter.h>
#include <geos/operation/distance/DistanceOp.h>
//#include <geos/operation/distance/GeometryLocation.h>

#endif

